@@ -16,13 +16,19 @@ from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
 from matplotlib.cm import jet
 from pygame.mixer import Sound, init, quit, get_init, set_num_channels
 
-def AE_init():
+def AE_install():
+	AE_path = os.path.join(os.path.split(os.path.realpath(__file__))[0],'AE')
 	if not os.path.isdir(AE_path):
 		print('Cloning the audio engine to the pyanthem package directory...')
 		Repo.clone_from('https://github.com/nicthib/AE.git',AE_path)
 		print('Audio engine downloaded to {}'.format(AE_path))
 	else:
 		print('Audio engine is already present in {}'.format(AE_path))
+		
+def AE_uninstall():
+	AE_path = os.path.join(os.path.split(os.path.realpath(__file__))[0],'AE')
+	os.remove(AE_path)
+	print('Audio engine uninstalled.')
 
 def init_entry(fn):
 	if isinstance(fn, str):
